#include <stdio.h>
#include "fprintfile.h"

static unsigned char h[FINGERPRINTFILE_HASHLEN];
static unsigned char input[1024];

void sum(fi,out)
FILE *fi;
char *out;
{
 fingerprintfile f;
 int i;

 fingerprintfile_clear(&f);
 while (i = fread(input,1,sizeof(input),fi))
   fingerprintfile_addn(&f,input,i);
 fingerprintfile_hash(&f,h);

 out[fingerprintfile_fmt(out,h)] = 0;
}
nt.c
echo x - summain.1
sed 's/^X//' >summain.1 << 'END-of-summain.1'
.TH summain 1
.SH NAME
summain \- generic checksum program interface
.SH SYNTAX
.I summain
[
.B \-cgfFiIbB\fP
] [
\fIfile ...\fP
]
.SH DESCRIPTION
.I summain
is a generic interface for programs which compute checksums.
There is no actual
.B summain
program.
Instead, several other programs,
such as
.B cksum
and
.B fingerprint\fP,
all conform to
the
.I summain
interface.

.I summain
computes checksums for some number of files.
Normally it takes the filenames as arguments,
opens the files in binary mode,
computes their checksums,
and prints the checksums (with filenames) on standard output.

A checksum never contains the characters tab, newline, or null.
Other features of a checksum depend on the particular program.

.I summain
follows the
.B getopt
standard.
Its options are summarized here.
.TP
.B \-b
Open files in binary mode (default).
.TP
.B \-B
Open files in text mode.
.TP
.B \-i
Read filenames from input, and ignore any filename arguments.
.TP
.B \-I
Use arguments as filenames (default).
If no arguments are given,
.I summain
reads the standard input as a file.
Otherwise it ignores
the input.
.TP
.B \-f
When the
.B \-i
option is in effect,
read input lines with the
same format as the usual output
of
.I summain\fP.
In other words, look for the first tab on each input line,
and use the filename following that tab.
.TP
.B \-F
When the
.B \-i
option is in effect,
read filenames as entire input lines (default).
.TP
.B \-g
Generate checksums (default).
.I summain
will print each checksum, followed by a tab and the
name of the file,
as a separate line on standard output.
The checksum of the standard input is printed with a tab
but no filename.
.TP
.B \-c
Check checksums.
This option forces
.B \-fi\fP.
.I summain
will read any number of input lines,
each containing a purported checksum, a tab, and a filename.
.I summain
will open each file, compute its checksum, and compare the
checksum to the purported checksum.
.SH "EXIT VALUE"
0 normally.
1 for usage messages.
2 if a file could not be opened for reading.
3 with option
.B \-c
if any checksums failed to match.
(Exit value 3 overrides exit value 2.)
.SH BUGS
None known.
.SH VERSION
summain version 0.9, 13 July 1993.
.SH AUTHOR
Placed into the public domain by Daniel J. Bernstein.
.SH "SEE ALSO"
.B cksum(1)\fP,
.B fingerprint(1)\fP,
.B md5(1)\fP,
.B snefru(1)\fP
END-of-summain.1
echo x - summain.c
sed 's/^X//' >summain.c << 'END-of-summain.c'
#include <stdio.h>
#include <errno.h>
extern int errno;
#include "getopt.h"

#define TAB '	' /*XXX*/

int flagcheck = 0;
int flagin = 0;
int flaghin = 0;
int flagbinary = 1;

int flagallmatch = 1;
int flagreaderr = 0;

char *oldhash; /* defined for the duration of doit, if flagcheck */

void doit(fi,fn)
FILE *fi;
char *fn;
{
 static char out[100];

 sum(fi,out);

 if (flagcheck)
  {
   if (strcmp(oldhash,out))
    {
     fprintf(stderr,"%s: warning: %s hash does not match\n"
       ,optprogname,fn);
     flagallmatch = 0;
    }
  }
 else
  {
   fputs(out,stdout);
   putchar(TAB);
   puts(fn);
  }
}

void handle(x)
char *x;
{
 FILE *fi;

 fi = fopen(x,flagbinary ? "rb" : "r");
 if (!fi)
  {
   int errnobak;
   errnobak = errno;
   fprintf(stderr,"%s: warning: cannot open %s for "
     ,optprogname,x);
   errno = errnobak;
   perror("reading");
   flagreaderr = 1;
  }
 else
  {
   doit(fi,x);
   fclose(fi);
  }
}

char line[1000];

main(argc,argv)
int argc;
char **argv;
{
 int opt;

 while ((opt = getopt(argc,argv,"cgfFiIbB")) != opteof)
   switch(opt)
    {
     case 'c': flagcheck = 1; break;
     case 'g': flagcheck = 0; break;
     case 'f': flaghin = 1; break;
     case 'F': flaghin = 0; break;
     case 'i': flagin = 1; break;
     case 'I': flagin = 0; break;
     case 'b': flagbinary = 1; break;
     case 'B': flagbinary = 0; break;
     case '?': default: exit(1);
    }
 argc -= optind;
 argv += optind;

 if (flagcheck)
   flagin = flaghin = 1;

 if (flagin)
   while (fgets(line,sizeof(line),stdin))
    {
     char *x;
     int len;
     x = line;
     if (flaghin)
      {
       while (*x && (*x != '\n') && (*x != TAB)) ++x;
       if (*x == TAB) *x++ = 0;
      }
     if (!*x) continue; /*XXX*/
     len = strlen(x);
     if (x[len - 1] == '\n') x[len - 1] = 0;
     if (!*x) continue; /*XXX*/
     if (flagcheck)
       oldhash = line;
     handle(x);
    }
 else
   if (*argv)
     while (*argv)
      {
       handle(*argv);
       ++argv;
      }
   else
     doit(stdin,""); /*XXX*/

 if (!flagallmatch)
   exit(3);
 if (flagreaderr)
   exit(2);
 exit(0);
}
END-of-summain.c
echo x - getopt.3
sed 's/^X//' >getopt.3 << 'END-of-getopt.3'
.TH getopt 3
.SH NAME
getopt \- get option character from command line
.SH SYNTAX
.B #include <getopt.h>

char *\fBoptarg\fP;
.br
int \fBoptind\fP;
.br
int \fBoptpos\fP;
.br
int \fBopteof\fP;
.br
int \fBoptproblem\fP;
.br
char *\fBoptprogname\fP;
.br
int \fBopterr\fP;

int \fBgetopt(\fP\fIargc,argv,opts\fR\fB)\fP;

int \fIargc\fR;
.br
char **\fIargv\fR;
.br
char *\fIopts\fR;
.SH DESCRIPTION
This is a clone version of
the standard
.B getopt
library,
built on top of
.BR subgetopt(3) .

See
.B subgetopt(3)
for a detailed description of
.B getopt
processing.
The main difference between
.B getopt
and
.B subgetopt
is that
.B getopt
prints error messages
in case of problems.
To turn off these error messages, set
.B opterr
(default nonzero)
to zero.

This clone version of
.B getopt
also provides an
.B optprogname
variable.
There are two uses for this variable:

(1)
By default
.B optprogname
is null.
When
.B getopt
sees this,
it
attempts to initialize
.B optprogname
from
.IR argv\fB[0] ,
stripping the directory name.
The calling program can use
.B optprogname
after calling
.B getopt
at least once.
This is appropriate if the name of the program should be
determined from its command line.

(2)
.B getopt
prints
.B optprogname
at the beginning
of any error messages.
So the calling program can,
before calling
.BR getopt ,
initialize
.B optprogname
as desired.
This is appropriate if the name of the program should not be
determined from its command line.
.SH "COMPATIBILITY"
Old versions of
.B getopt
do not include
.BR opterr .
.BR optpos ,
.BR opteof ,
.BR optproblem ,
and
.B optprogname
are specific to this clone version of
.BR getopt .

Many features of this clone version of
.B getopt
are poorly defined, if available at all,
in most versions of
.BR getopt .
For example, the standard
.B getopt
interface does not define
.B optind
until the end of the option list.
And
.B optarg
is not defined
unless
.B getopt
has just returned
an option which takes an argument.
In this clone version,
.B optind
and
.B optpos
always indicate the next character to be read,
and
.B optarg
is null whenever
the current option does not take an argument.
See
.B subgetopt(3)
for precise definitions of the parsing procedure.

When it reaches the end of the option list,
this version of
.B getopt
always returns
.BR opteof ,
which is the same as
.BR subgetoptdone ,
which is initialized to
.BR SUBGETOPTDONE ,
which is defined as \-1.
The standard behavior is to return
EOF
from
.B stdio(3).
This is incompatible
on any weird machine where
EOF is different from \-1.
The calling program could set
.B opteof
to EOF to imitate the standard behavior.

Like most versions of
.BR getopt ,
this clone version allows, but does not demand, that
option arguments be
separated from the option by whitespace, i.e., be
in the next command-line argument.

Some versions of
.B getopt
provide an
.B optopt
variable.
.B optopt
is incompatible across systems:
for example,
GNU
.B getopt
uses it the same way that this clone version uses
.BR optproblem ,
while
BSD
.B getopt
uses it to
ter returned by
.BR getopt .
This clone version does not provide
.BR optopt .
The use of
.B optopt
is strongly discouraged.

Some versions of
.B getopt
do not recognize a double hyphen as the end of arguments.
This version allows a double hyphen, or in fact any argument beginning
with two hyphens.

A lone hyphen is always recognized as the end of arguments.
Some versions of
.B getopt
allow lone hyphens as options.
This practice is wrong and is strongly discouraged.
.SH "SYNTAX NOTE"
.B getopt
is actually a macro abbreviation for
.BR getoptmine .
The external
.B opterr
and
.B optprogname
variables
are macros for
.B getopterr
and
.BR getoptprogname .
All the other
.B opt
variables are macros
for
.BR subgetopt .
These macros are defined in
.BR <getopt.h> ,
unless
.B GETOPTNOSHORT
is defined.
Further macros are defined in
.BR <subgetopt.h> ,
which is included by
.BR <getopt.h> ,
unless
.B SUBGETOPTNOSHORT
is defined.
.SH VERSION
getopt version 1.9, 931129.
.SH AUTHOR
Placed into the public domain by Daniel J. Bernstein.
END-of-getopt.3
echo x - getopt.h
sed 's/^X//' >getopt.h << 'END-of-getopt.h'
#ifndef GETOPT_H
#define GETOPT_H

#ifndef GETOPTNOSHORT
#define getopt getoptmine
#define optarg subgetoptarg
#define optind subgetoptind
#define optpos subgetoptpos
#define opterr getopterr
#define optproblem subgetoptproblem
#define optprogname getoptprogname
#define opteof subgetoptdone
#endif

#include "subgetopt.h"

extern int getoptmine();
extern int getopterr;
extern char *getoptprogname;

#endif
END-of-getopt.h
echo x - getopt.c
sed 's/^X//' >getopt.c << 'END-of-getopt.c'
/* getopt.c, getopt.h: (yet another) improved getopt clone, outer layer
Daniel J. Bernstein, djb@silverton.berkeley.edu.
Depends on subgetopt.h.
Requires stdio.
931129: Rewrote in terms of subgetopt.
No known patent problems.

Documentation in getopt.3.
*/

#include <stdio.h>
#define GETOPTNOSHORT
#include "getopt.h"
#define SUBGETOPTNOSHORT
#include "subgetopt.h"

#define getopt getoptmine
#define optind subgetoptind
#define opterr getopterr
#define optproblem subgetoptproblem
#define optprogname getoptprogname

int opterr = 1;
char *optprogname = 0;

int getopt(argc,argv,opts)
int argc;
char **argv;
char *opts;
{
 int c;
 char *s;

 if (!optprogname)
  {
   optprogname = *argv;
   if (!optprogname) /* oh boy */
     optprogname = ""; /*XXX*/
   for (s = optprogname;*s;++s)
     if (*s == '/')
       optprogname = s + 1;
  }
 c = subgetopt(argc,argv,opts);
 if (opterr)
   if (c == '?')
     if (argv[optind] && (optind < argc))
       fprintf(stderr,"%s: illegal option -- %c\n",optprogname,optproblem);
     else
       fprintf(stderr,"%s: option requires an argument -- %c\n"
         ,optprogname,optproblem);
 return c;
}
END-of-getopt.c
echo x - subgetopt.3
sed 's/^X//' >subgetopt.3 << 'END-of-subgetopt.3'
.TH subgetopt 3
.SH NAME
subgetopt \- get option character from command line
.SH SYNTAX
.B #include <subgetopt.h>

char *\fBsgoptarg\fP;
.br
int \fBsgoptind\fP;
.br
int \fBsgoptpos\fP;
.br
int \fBsgoptdone\fP;
.br
int \fBsgoptproblem\fP;

int \fBsgopt(\fP\fIargc,argv,opts\fR\fB)\fP;

int \fIargc\fR;
.br
char **\fIargv\fR;
.br
char *\fIopts\fR;
.SH DESCRIPTION
.B sgopt
returns the next valid command-line option character
from
.IR argv .

Valid option characters are listed in the
.I opts
string.
.I opts
may be empty.
A character in
.I opts
may be followed by a colon,
in which case it
takes an
.I option argument\fR.
Avoid using the characters ?, :, and \- as option characters.

Below
.I option argument
is abbreviated
as
.I optarg
and
.I command-line argument
is abbreviated as
.IR cmdarg .

Options are listed in cmdargs which begin with
a minus sign.
Several options which do not take optargs may be combined
into one cmdarg.

An option which takes an optarg may be handled in two ways.
If it appears at the very end of a cmdarg,
then the entire next cmdarg is the optarg.
But if there are any characters in the cmdarg
after the option character,
then those characters form the optarg.
The optarg is returned in
.BR sgoptarg .
Next time
.B sgopt
looks at the cmdarg which follows the optarg.

If a cmdarg does not begin with a hyphen,
or if it is a lone hyphen not followed by any characters,
or if it begins with two hyphens,
then it terminates option processing,
and
.B sgopt
returns an appropriate code.
If there are two hyphens,
.B sgopt
will advance attention to the next cmdarg,
so it can be called again to read further options.
.SH "PROPER USAGE"
.B sgoptproblem
should be used only when
.B sgopt
returns ?.
.B sgoptind
and
.B sgoptpos
are defined all the time.
.B sgoptarg
is defined all the time;
it is null unless
.B sgopt
has just returned an option with optarg.

.B sgopt
is typically used as follows.

.EX
#include <subgetopt.h>

main(argc,argv) int argc; char **argv; { int opt;

while ((opt = sgopt(argc,argv,"a:s")) != sgoptdone)
.br
  switch(opt) {
.br
    case 'a':
.br
      printf("opt a with optarg %s\\n",sgoptarg); break;
.br
    case 's':
.br
      printf("opt s with no optarg\\n"); break;
.br
    case '?':
.br
      if (argv[sgoptind] && (sgoptind < argc))
.br
        printf("illegal opt %c\\n",sgoptproblem);
.br
      else
.br
        printf("missing arg, opt %c\\n",sgoptproblem);
.br
      exit(1);
.br
  }

argv += sgoptind;
.br
while (*argv) printf("argument %s\\n",*argv++);
.br
exit(0);
.br
}
.EE

The end of the command line is
marked by either
.IR argc ,
or a null pointer in
.IR argv ,
whichever comes first.
Normally
these two markers coincide,
so it is redundant
to test for
both
.I argv\fB[sgoptind]
and
.B sgoptind < \fIargc\fR.
The above code shows both tests as an illustration.

.B Multiple option sets:
One useful technique is to call
.B sgopt
with a primary
.I opts
until it returns EOF,
then call
.B sgopt
with a secondary
.I opts
until it returns EOF.
The user can provide primary options, then a double hyphen,
and then secondary options.
No special handling is needed if some or all of the options are
omitted.
The same technique can be used for any number of option sets
in series.

.B Multiple command lines:
Before parsing a new
.BR argv ,
make sure to
set
.B sgoptind
and
.B sgoptpos
back to
1 and 0.
.SH "PARSING STAGES"
.B sgopt
keeps track of its position in
.I argv
with
.B sgoptind
and
.BR sgoptpos ,
which are initialized to 1 and 0.
It looks at
.I argv\fB[sgoptind][sgoptpos]
and following characters.

.B sgopt
indicates
that no more options are available by
returning
.BR sgoptdone ,
which is initialized to
.BR SUBGETOPTDONE ,
which is defined as \-1.

.B sgopt
begins by setting
.B optarg
to null.

.B Ending conditions:
If
.I argv
is null, or
.B sgoptind
is larger than
.IR argc ,
or the current cmdarg
.I argv\fB[sgoptind]
is null,
then
.B sgopt
returns
.BR optdone .

.B Stage one:
If the current character
is zero,
.B sgopt
moves to the beginning of the next cmdarg.
It then checks the ending conditions again.

.B Stage two:
If
the current position is the begining of the cmdarg,
.B sgopt
checks whether
the current character
is a minus sign.
If not it returns
.BR optdone .
It then
moves
to the next character.
If that character is zero,
.B sgopt
moves
back to the beginning of the cmdarg,
and returns
.BR sgoptdone .
If the character is a minus sign,
.B sgopt
moves to the beginning of the next cmdarg,
and returns
.BR sgoptdone .

.B Stage three:
.B sgopt
records the current character,
.IR c ,
and moves to the next character.
There are three possibilities:
(1)
.I c
is an option character without optarg in
.IR opts ,
or
(2)
.I c
is an option character with optarg in
.IR opts ,
or
(3)
.I c
does not appear in
.IR opts .

(1)
If
.I c
appears as an option character without optarg in
.IR opts ,
.B sgopt
returns
.IR c .

(2)
If
.I c
with optarg in
.IR opts ,
.B sgopt
sets
.B sgoptarg
to the current position,
and moves to the next cmdarg.
If
.B sgoptarg
is nonempty,
.B sgopt
returns
.IR c .

Then
.B sgopt
sets
.B sgoptarg
to
the current cmdarg.
If
the current cmdarg is null,
or past
.IR argc ,
.B sgopt
sets
.B sgoptproblem
to
.I c
and returns ?.
Otherwise
.B sgopt
moves to the next
argument
and returns
.IR c .

(2)
If
.I c
does not appear in
.IR opts ,
.B sgopt
sets
.B sgoptproblem
to
.I c
and returns ?.
.SH "SYNTAX NOTE"
.B sgopt
is actually a macro abbreviation for
.BR subgetopt .
The external
.B sg
variables are also macros
for
.BR subget .
These macros are defined in
.BR <subgetopt.h> ,
unless
.B SUBGETOPTNOSHORT
is defined
when
.B <subgetopt.h>
is included.
.SH VERSION
subgetopt version 0.9, 931129.
.SH AUTHOR
Placed into the public domain by Daniel J. Bernstein.
END-of-subgetopt.3
echo x - subgetopt.h
sed 's/^X//' >subgetopt.h << 'END-of-subgetopt.h'
#ifndef SUBGETOPT_H
#define SUBGETOPT_H

#ifndef SUBGETOPTNOSHORT
#define sgopt subgetopt
#define sgoptarg subgetoptarg
#define sgoptind subgetoptind
#define sgoptpos subgetoptpos
#define sgoptproblem subgetoptproblem
#define sgoptprogname subgetoptprogname
#define sgoptdone subgetoptdone
#endif

#define SUBGETOPTDONE -1

extern int subgetopt();
extern char *subgetoptarg;
extern int subgetoptind;
extern int subgetoptpos;
extern int subgetoptproblem;
extern char *subgetoptprogname;
extern int subgetoptdone;

#endif
END-of-subgetopt.h
echo x - subgetopt.c
sed 's/^X//' >subgetopt.c << 'END-of-subgetopt.c'
/* subgetopt.c, subgetopt.h: (yet another) improved getopt clone, inner layer
Daniel J. Bernstein, djb@silverton.berkeley.edu.
No dependencies.
No system requirements.
931129: Adapted from getopt.c.
No known patent problems.

Documentation in subgetopt.3.
*/

#define SUBGETOPTNOSHORT
#include "subgetopt.h"

#define sgopt subgetopt
#define optind subgetoptind
#define optpos subgetoptpos
#define optarg subgetoptarg
#define optproblem subgetoptproblem
#define optdone subgetoptdone

int optind = 1;
int optpos = 0;
char *optarg = 0;
int optproblem = 0;
int optdone = SUBGETOPTDONE;

int sgopt(argc,argv,opts)
int argc;
char **argv;
char *opts;
{
 int c;
 char *s;

 optarg = 0;
 if (!argv || (optind >= argc) || !argv[optind])
   return optdone;
 if (optpos && !argv[optind][optpos])
  {
   ++optind;
   optpos = 0;
   if ((optind >= argc) || !argv[optind])
     return optdone;
  }
 if (!optpos)
  {
   if (argv[optind][0] != '-')
     return optdone;
   ++optpos;
   c = argv[optind][1];
   if ((c == '-') || (c == 0))
    {
     /* XXX: this behavior of "-" is stupid */
     if (c)
       ++optind;
     optpos = 0;
     return optdone;
    }
   /* otherwise c is reassigned below */
  }
 c = argv[optind][optpos];
 ++optpos;
 s = opts;
 while (*s)
  {
   if (c == *s)
    {
     if (s[1] == ':')
      {
       optarg = argv[optind] + optpos;
       ++optind;
       optpos = 0;
       if (!*optarg)
        {
         optarg = argv[optind];
         if ((optind >= argc) || !optarg) /* argument past end */
          {
           optproblem = c;
           return '?';
          }
	 ++optind;
        }
      }
     return c;
    }
   ++s;
   if (*s == ':')
     ++s;
  }
 optproblem = c;
 return '?';
}
END-of-subgetopt.c
echo x - TIMINGS
sed 's/^X//' >TIMINGS << 'END-of-TIMINGS'
K/sec timings are based on a few trials. Megabyte timings are based on
one trial. More accurate timings would be nice, but I figure that a
haphazard collection of rough timings is better than nothing at all.

SPARC, Sun 4, SunOS 4.1.3, cc -O4
fingerprint: 127K/sec
snefru: 139K/sec
md5: 2304K/sec
cksum: 3585K/sec
compress: 190K/sec

SPARC, Sun 4, SunOS 4.1.3, gcc -O
fingerprint: 138K/sec
snefru: 150K/sec
md5: 2300K/sec
cksum: 4600K/sec
compress: 190K/sec

SPARC, Sun 4, SunOS 4.1.1, cc -O4
fingerprint: 95K/sec
snefru: 115K/sec
md5: 913K/sec
cksum: 1644K/sec
compress: 153K/sec

SPARC Classic/SPARC IPX, Solaris 2.1, gcc (2.5.4), 32M memory (tnx CC)
fingerprint: 7.97u 1.61s
snefru: 6.08u 1.20s
md5: 0.99u 0.68s
cksum: 0.47u 0.70s
compress: 5.38u 1.35s

SS10 Model 30, SunOS 4.1.3 (tnx JL)
fingerprint: 8.5u 0.0s
snefru: 7.7u 0.0s
md5: 0.5u 0.0s
cksum: 0.3u 0.0s
compress: 3.5u 0.1s

SGI, ?, cc -O2 -cckr
fingerprint: 157K/sec
snefru: 188K/sec
md5: 1309K/sec
cksum: 2216K/sec
compress: 139.4K/sec

NeXT, ?, cc -O
fingerprint: 60.5K/sec
snefru: 72.3K/sec
md5: 528K/sec
cksum: 1300K/sec
compress: 130K/sec

NeXT, NeXT Mach 3.1, gcc (2.5.4), 24M memory (tnx CC)
fingerprint: 16.49u 0.80s
snefru: 14.17u 0.47s
md5: 1.54u 0.32s
cksum: 0.79u 0.39s
compress: 6.01u 0.45s

MIPS, DECstation 5000, Ultrix 4.2A (47), cc -O2
fingerprint: 121K/sec
snefru: 148K/sec
md5: 1128K/sec
cksum: 1812K/sec
compress: 157K/sec

MIPS, DECstation 5000, Ultrix 4.2A (47), gcc -O
fingerprint: 110K/sec
snefru: 144K/sec
md5: 927K/sec
cksum: 2098K/sec
compress: 157K/sec

MIPS, DECstation 5000/25, Ultrix 4.2A, gcc (2.5.4), 40M memory (tnx CC)
fingerprint: 10.12u 0.43s
snefru: 8.24u 0.50s
md5: 1.22u 0.34s
cksum: 0.54u 0.37s
compress: 7.80u 0.63s

VAXstation 3100, BSD 4.3, gcc (2.5.4), 8M memory (tnx CC)
fingerprint: 48.52u 1.74s
snefru: 41.6u 1.15s
md5: 4.70u 0.84s
cksum: 3.21u 0.95s
compress: 18.10u 2.54s

Intel 386/40, BSDI 1.0, cc -O, 64k (?) cache
fingerprint: 38.9K/sec
snefru: 51.6K/sec
md5: 323.7K/sec
cksum: 589.7K/sec
compress: 104.5K/sec

Intel 486/??, Linux 0.99.13, gcc (2.5.4), 16M memory (tnx CC)
fingerprint: 20.66u 0.49s
snefru: 18.22u 0.40s
md5: 1.57u 0.32s
cksum: 1.05u 0.27s
compress: 7.37u 0.45s

Intel 486/66DX2, SCO Open Server 3.0, cc -O (Microsoft C 6.0), EISA (tnx GS)
fingerprint: 90K/sec
snefru: 101K/sec
md5: 666K/sec
cksum: 1234K/sec
compress: 204K/sec

IBM RS/6000 320H, AIX 3.2, gcc (2.5.4), 16M memory (tnx CC)
fingerprint: 10.80u 0.15s
snefru: 9.19u 0.09s
md5: 1.00u 0.07s
cksum: 0.63u 0.08s
compress: 4.64u 0.10s

Pyramid MIServer 4/2T, OSx 5.1a, cc (tnx KV)
fingerprint: 38.1K/sec
snefru: 49.2K/sec
md5: 357K/sec
cksum: 526K/sec
compress: 84K/sec

HP9000/735, HP-UX 9.01, cc -O (tnx WL)
fingerprint: 660K/sec
snefru: 830K/sec
md5: 3300K/sec
cksum: 10000K/sec
compress: 1000K/sec

vangogh (HP?), cc -O
fingerprint: 61.6K/sec
snefru: 72.5K/sec
md5: 580K/sec
cksum: 1200K/sec
compress: 99.5K/sec
END-of-TIMINGS
echo x - fingerprint.tests
sed 's/^X//' >fingerprint.tests << 'END-of-fingerprint.tests'
9hX04ha9c7F23oV5wWEtGIVWUt:pH07srkl0QOfGsxbensg6BNEd:g8VQIDhn:QZ00VtVu05Kipu	snefru512.c
END-of-fingerprint.tests
echo x - md5.tests
sed 's/^X//' >md5.tests << 'END-of-md5.tests'
16344b673995a9049736209bf7ab5779	snefru512.c
END-of-md5.tests
echo x - snefru.tests
sed 's/^X//' >snefru.tests << 'END-of-snefru.tests'
 49a81803 84463870 1474b424 25867457 9773aebc 3b4c9ce7 aaef779b f400d781	snefru512.c
END-of-snefru.tests
echo x - cksum.tests
sed 's/^X//' >cksum.tests << 'END-of-cksum.tests'
3188261980    60030	snefru512.c
END-of-cksum.tests
exit

